using System;
using System.IO;
using Server;
using Server.Mobiles;
using SevenZip;

namespace Server.Misc
{
    [PropertyObject]
    public sealed class AutoSaveSettings
    {
        public override string ToString()
        {
            return @"Save Settings";
        }

        private static TimeSpan m_Delay;
        private static TimeSpan m_Warning;
        private static TimeSpan m_Warning2;
        private static bool m_SavesEnabled;
        private static int m_NoIOHour;
        private static CompressionLevel m_CompressionLevel;
        private static TimeSpan m_SaveStoneDelay;
        private static AccessLevel m_SaveStoneAccess;

        [CommandProperty(AccessLevel.Administrator)]
        public static TimeSpan Delay
        {
            get { return m_Delay; }
            set { m_Delay = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static TimeSpan Warning
        {
            get { return m_Warning; }
            set { m_Warning = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static TimeSpan Warning2
        {
            get { return m_Warning2; }
            set { m_Warning2 = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static TimeSpan SaveStoneDelay
        {
            get { return m_SaveStoneDelay; }
            set { m_SaveStoneDelay = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static AccessLevel SaveStoneAccess
        {
            get { return m_SaveStoneAccess; }
            set { m_SaveStoneAccess = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static bool SavesEnabled
        {
            get { return m_SavesEnabled; }
            set { m_SavesEnabled = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static int NoIOHour
        {
            get { return m_NoIOHour; }
            set { m_NoIOHour = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static CompressionLevel CompressionLevel
        {
            get { return m_CompressionLevel; }
            set { m_CompressionLevel = value; }
        }

        public AutoSaveSettings(TimeSpan delay, TimeSpan warning, bool savesEnabled, int noIOHour, CompressionLevel compressionLevel)
        {
            m_Delay = delay;
            m_Warning = warning;
            m_SavesEnabled = savesEnabled;
            m_NoIOHour = noIOHour;
            m_CompressionLevel = compressionLevel;
            m_Warning2 = TimeSpan.FromSeconds(30.0);
            m_SaveStoneDelay = TimeSpan.FromHours(2.0);
            m_SaveStoneAccess = AccessLevel.GameMaster;
        }

        public AutoSaveSettings(GenericReader reader)
        {
            Deserialize(reader);
        }

        public void Serialize(GenericWriter writer)
        {
            writer.Write(1);

            writer.Write(m_Warning2);
            writer.Write(m_SaveStoneDelay);
            writer.Write((byte)m_SaveStoneAccess);

            writer.Write(m_Delay);
            writer.Write(m_Warning);
            writer.Write(m_SavesEnabled);
            writer.Write(m_NoIOHour);
            writer.Write((byte)m_CompressionLevel);
        }

        public static void Deserialize(GenericReader reader)
        {
            int version = reader.ReadInt();

            switch (version)
            {
                case 1:
                    {
                        m_Warning2 = reader.ReadTimeSpan();
                        m_SaveStoneDelay = reader.ReadTimeSpan();
                        m_SaveStoneAccess = (AccessLevel)reader.ReadByte();
                        goto case 0;
                    }
                case 0:
                    {
                        m_Delay = reader.ReadTimeSpan();
                        m_Warning = reader.ReadTimeSpan();
                        m_SavesEnabled = reader.ReadBool();
                        m_NoIOHour = reader.ReadInt();
                        m_CompressionLevel = (CompressionLevel)reader.ReadByte();
                        break;
                    }
            }
            if (m_Warning2 == null)
                m_Warning2 = TimeSpan.FromSeconds(30.0);
            if (m_SaveStoneDelay == null)
                m_SaveStoneDelay = TimeSpan.FromHours(2.0);
            if (m_SaveStoneAccess == null)
                m_SaveStoneAccess = AccessLevel.GameMaster;
        }
    }
}