using System;
using Server;
using Server.Items;
using Server.Commands;
using Server.Misc;

namespace Server.Items
{
    public class SaveStone : Item
    {
        private static Mobile m_Owner;
        private static DateTime m_LastUsed;

        [CommandProperty(AccessLevel.Administrator)]
        public static Mobile Owner
        {
            get { return m_Owner; } set { m_Owner = value; }
        }

        [CommandProperty(AccessLevel.Administrator)]
        public static DateTime LastUsed
        {
            get { return m_LastUsed; } set { m_LastUsed = value; }
        }

        [Constructable]
        public SaveStone()
            : base(0x1F1C)
        {
            Name = "A Save Stone";
            Movable = true;
            LootType = LootType.Blessed;
            Hue = 2578;
            Owner = null;
            LastUsed = DateTime.Now - AutoSaveSettings.SaveStoneDelay;
        }

        public SaveStone(Serial serial)
            : base(serial)
        {
        }

        public override void OnDoubleClick(Mobile from)
        {
            if (IsChildOf(from.Backpack))
            {
                if (from.AccessLevel >= AutoSaveSettings.SaveStoneAccess)
                {
                    if (Owner == null)
                    {
                        m_Owner = from;
                        this.Name = m_Owner.Name.ToString() + "'s Save Stone";
                        from.SendMessage("This save stone has been assigned to you.");
                    }
                    else if (Owner == from)
                    {
                        if ((DateTime.Now - m_LastUsed) >= AutoSaveSettings.SaveStoneDelay)
                        {
                            m_LastUsed = DateTime.Now;
                            Misc.AutoSave.Save();
                        }
                        else
                        {
                            from.SendMessage("You must wait before trying to save the shard again.");
                        }
                    }
                    else
                    {
                        from.SendMessage("That save stone does not belong to you!");
                        this.Delete();
                    }
                }
                else
                {
                    from.SendMessage("You don't posses the access level required to use this!");
                    from.Delete();
                }
            }
            else
            {
                from.SendLocalizedMessage(1042001);
            }
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);

            writer.Write(0);

            writer.Write(m_Owner);
            writer.Write(m_LastUsed);
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);

            int version = reader.ReadInt();

            switch (version)
            {
                case 0:
                    {
                        m_Owner = reader.ReadMobile();
                        m_LastUsed = reader.ReadDateTime();
                        break;
                    }
            }
        }
    }
}